@@ -22,19 +22,20 @@
  */
 
 /*
- *       $Source: /home/anidel/Wip/TCFS-2.2.0a/tcfsutils-1.1/src/RCS/show_usage.c,v $
+ *       $Source: /home/anidel/Wip/TCFS-2.2.0a/tcfsutils-1.2.1/src/RCS/show_usage.c,v $
  *        $State: Exp $
  *
  *     $Revision: 2.0 $
  *       $Author: anidel $
  *         $Date: 1998/10/22 08:40:09 $
- *       $Locker:  $
+ *       $Locker: anidel $
  */
 
-static const char *RCSid="$Id: show_usage.c,v 2.0 1998/10/22 08:40:09 anidel Exp $";
+static const char *RCSid="$Id: show_usage.c,v 2.0 1998/10/22 08:40:09 anidel Exp anidel $";
 /* -+-_== */ 
 
 void show_usage (char *fmt, char *arg)
 {
+	printf ("TCFS Utilities v.%d.%d.%d\n", MAJOR, MINOR, RELEASE);
 	printf (fmt, arg);
 }
